<?php

namespace Realestate\Sample\Policies;

use Litepie\User\Contracts\UserPolicy;
use Realestate\Sample\Models\Insert;

class InsertPolicy
{

    /**
     * Determine if the given user can view the insert.
     *
     * @param UserPolicy $user
     * @param Insert $insert
     *
     * @return bool
     */
    public function view(UserPolicy $user, Insert $insert)
    {
        if ($user->canDo('sample.insert.view') && $user->isAdmin()) {
            return true;
        }

        return $insert->user_id == user_id() && $insert->user_type == user_type();
    }

    /**
     * Determine if the given user can create a insert.
     *
     * @param UserPolicy $user
     * @param Insert $insert
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('sample.insert.create');
    }

    /**
     * Determine if the given user can update the given insert.
     *
     * @param UserPolicy $user
     * @param Insert $insert
     *
     * @return bool
     */
    public function update(UserPolicy $user, Insert $insert)
    {
        if ($user->canDo('sample.insert.edit') && $user->isAdmin()) {
            return true;
        }

        return $insert->user_id == user_id() && $insert->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given insert.
     *
     * @param UserPolicy $user
     * @param Insert $insert
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Insert $insert)
    {
        return $insert->user_id == user_id() && $insert->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given insert.
     *
     * @param UserPolicy $user
     * @param Insert $insert
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Insert $insert)
    {
        if ($user->canDo('sample.insert.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given insert.
     *
     * @param UserPolicy $user
     * @param Insert $insert
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Insert $insert)
    {
        if ($user->canDo('sample.insert.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
